aboutsummaryrefslogtreecommitdiffstats
path: root/sys/targets
diff options
context:
space:
mode:
authorStefan Wiehler <me@sephalon.net>2024-12-02 16:00:37 +0100
committerDmitry Vyukov <dvyukov@google.com>2024-12-17 11:13:44 +0000
commitbc1a1b50f942408a9139887b914f745d9fa02adc (patch)
tree1c41777ce9ba26e8efe80e3fc6d717bde44be707 /sys/targets
parentf93b2b552ce5fe589b450ff74ca1b459cdbc71a8 (diff)
all: add support for binaries shipped with target
In some build environments (notably Yocto), syzkaller host and target binaries end up in separate packages for each built architecture, which are then shipped with the respective image/SDK. Add the "Execprog/ExecutorBinOnTarget" and "StraceBinOnTarget" options to the manager config, which when set expects the respective binaries to be shipped with the target image and does not attempt to copy them from the host.
Diffstat (limited to 'sys/targets')
-rw-r--r--sys/targets/targets.go7
1 files changed, 4 insertions, 3 deletions
diff --git a/sys/targets/targets.go b/sys/targets/targets.go
index a623dbfb6..38ebeb365 100644
--- a/sys/targets/targets.go
+++ b/sys/targets/targets.go
@@ -82,10 +82,11 @@ type osCommon struct {
// Special mode for OSes that do not have support for building Go binaries.
// In this mode we run Go binaries on the host machine, only executor runs on target.
HostFuzzer bool
// How to run syz-executor directly.
// Some systems build syz-executor into their images.
// If this flag is not empty, syz-executor will not be copied to the machine, and will be run using
// this command instead.
+ ExecprogBin string
ExecutorBin string
// Extension of executable files (notably, .exe for windows).
ExeExtension string
@@ -82,10 +82,11 @@ type osCommon struct {
// In this mode we run Go binaries on the host machine, only executor runs on target.
HostFuzzer bool
- // How to run syz-executor directly.
- // Some systems build syz-executor into their images.
- // If this flag is not empty, syz-executor will not be copied to the machine, and will be run using
+ // How to run syz-execprog/executor directly.
+ // Some systems build syz-execprog/executor into their images.
+ // If this flag is not empty, syz-execprog/executor will not be copied to the machine, and will be run using
// this command instead.